parserFwk.pyparsing.NotAny

Package parserFwk :: Module pyparsing :: Class NotAny |
[frames | no frames]

## Type NotAny

         object --+
                  |
      ParserElement --+
                      |
    ParseElementEnhance --+
                          |
                         NotAny

Lookahead to disallow matching with the given parse expression. NotAny does *not* advance the parsing position within the input string, it only verifies that the specified parse expression does *not* match at the current position. Also, NotAny does *not* skip over leading whitespace. NotAny always returns a null token list. May be constructed using the '~' operator.

Method Summary
| `__init__(self, expr)`
| `__str__(self)`
| `parseImpl(self, instring, loc, doActions)`
Inherited from `ParseElementEnhance`: `checkRecursion`, `ignore`, `leaveWhitespace`, `streamline`, `validate` Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__getattr__`, `__invert__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__ror__`, `__rxor__`, `__xor__`, `addParseAction`, `copy`, `enablePackrat`, `getException`, `normalizeParseActionArgs`, `parseFile`, `parseString`, `parseWithTabs`, `postParse`, `preParse`, `resetCache`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setDefaultWhitespaceChars`, `setFailAction`, `setName`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `skipIgnorables`, `suppress`, `transformString`, `tryParse` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variable Summary
`list` | `__slotnames__` = `[]`
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`

Class Variable Details

    ### __slotnames__ Type: `list` Value:
        []

Generated by Epydoc 2.1 on Sun Oct 07 01:31:52 2007 | http://epydoc.sf.net